OpStatusCode

Enum OpStatusCode 

#[repr(u32)]
pub enum OpStatusCode {
Show 57 variants Unknown = 0, InvalidHexLength = 1, HexParsingFailed = 2, InvalidNoteLength = 3, InvalidNoteProtocol = 4, InvalidNoteVersion = 5, InvalidNoteId = 6, InvalidNoteBlockNumber = 7, InvalidNoteSecrets = 8, MerkleTreeNotFound = 9, SerializationFailed = 10, DeserializationFailed = 11, InvalidArrayLength = 12, InvalidCurve = 13, InvalidHasFunction = 14, InvalidBackend = 15, InvalidDenomination = 16, SecretGenFailed = 17, InvalidSourceChain = 18, InvalidTargetChain = 19, InvalidTokenSymbol = 20, InvalidExponentiation = 21, InvalidWidth = 22, InvalidAmount = 23, InvalidProofParameters = 24, InvalidProvingKey = 25, InvalidRecipient = 26, InvalidRelayer = 27, InvalidLeafIndex = 28, InvalidFee = 29, InvalidRefund = 30, InvalidLeaves = 31, FailedToGenerateTheLeaf = 32, ProofBuilderNoteNotSet = 33, CommitmentNotSet = 34, RootsNotSet = 35, InvalidNoteMiscData = 36, InvalidSourceIdentifyingData = 37, InvalidTargetIdentifyingData = 38, UnsupportedParameterCombination = 39, InvalidProof = 40, InvalidUTXOIndex = 41, UnsupportedBackend = 42, PublicAmountNotSet = 43, VAnchorProofChainId = 44, VAnchorNotesNotSet = 45, VAnchorProofIndices = 46, VAnchorProofLeavesMap = 47, ProofInputFieldInstantiationError = 48, ProofInputFieldInstantiationProtocolInvalid = 49, InvalidNullifer = 50, InvalidRoots = 51, InvalidChainId = 52, InvalidIndices = 53, InvalidPublicAmount = 54, InvalidOutputUtxoConfig = 55, InvalidExtDataHash = 56,
}

Variants



Unknown = 0



InvalidHexLength = 1

Invalid hex string length when decoding



HexParsingFailed = 2

Failed to parse hex string



InvalidNoteLength = 3

Invalid number of note parts when decoding



InvalidNoteProtocol = 4

Invalid note protocol



InvalidNoteVersion = 5

Invalid note version



InvalidNoteId = 6

Invalid note id when parsing



InvalidNoteBlockNumber = 7

Invalid note block number when parsing



InvalidNoteSecrets = 8

Invalid note secrets



MerkleTreeNotFound = 9

Unable to find merkle tree



SerializationFailed = 10

Failed serialization of passed params Error for failing to parse rust type into JsValue



DeserializationFailed = 11

Failed deserialization of JsValue into rust type



InvalidArrayLength = 12

Invalid Array of 32 bytes.



InvalidCurve = 13

Invalid curve when parsing



InvalidHasFunction = 14

Invalid hashFunction id when parsing



InvalidBackend = 15

Invalid backend id when parsing



InvalidDenomination = 16

Invalid denomination id when parsing



SecretGenFailed = 17

Failed to generate secrets



InvalidSourceChain = 18

Invalid Source chain



InvalidTargetChain = 19

Invalid target chain



InvalidTokenSymbol = 20

Invalid Token Symbol



InvalidExponentiation = 21

Invalid Exponentiation



InvalidWidth = 22

Invalid Width



InvalidAmount = 23

Invalid Amount



InvalidProofParameters = 24

Invalid proof parameters



InvalidProvingKey = 25

Invalid Proving key



InvalidRecipient = 26

Invalid Recipient



InvalidRelayer = 27

Invalid Relayer



InvalidLeafIndex = 28

Invalid LeafIndex



InvalidFee = 29

Invalid Fee



InvalidRefund = 30

Invalid Refund



InvalidLeaves = 31

Invalid InvalidLeaves



FailedToGenerateTheLeaf = 32

Failed to Generating Leaf



ProofBuilderNoteNotSet = 33

Note not set



CommitmentNotSet = 34

Commitment not set



RootsNotSet = 35

Neighbour Roots aren’t set



InvalidNoteMiscData = 36

Invalid note misc data



InvalidSourceIdentifyingData = 37

Invalid Source IdentifyingData



InvalidTargetIdentifyingData = 38

Invalid target IdentifyingData



UnsupportedParameterCombination = 39

Unsupported combination of parameters



InvalidProof = 40

Invalid proof on verification



InvalidUTXOIndex = 41

Invalid index



UnsupportedBackend = 42

Unsupported Backend



PublicAmountNotSet = 43

Public amount not set



VAnchorProofChainId = 44

VAnchor Proof Chain Id not set



VAnchorNotesNotSet = 45

VAnchor proof not set



VAnchorProofIndices = 46

VAnchor proof indices



VAnchorProofLeavesMap = 47

VAnchor proof leaves map not defined



ProofInputFieldInstantiationError = 48

Generic error while trying to instantiate proof input field



ProofInputFieldInstantiationProtocolInvalid = 49

Invalid filed for the proof input protocol



InvalidNullifer = 50



InvalidRoots = 51



InvalidChainId = 52



InvalidIndices = 53



InvalidPublicAmount = 54



InvalidOutputUtxoConfig = 55



InvalidExtDataHash = 56